#
# spec file for package python-pyfiglet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyfiglet
Version:        1.0.2
Release:        1.4
Summary:        Pure Python FIGlet implementation
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pwaller/pyfiglet
Source:         https://files.pythonhosted.org/packages/source/p/pyfiglet/pyfiglet-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  figlet
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
PyFIGlet is a full port of FIGlet (http://www.figlet.org/) into pure
Python. It takes ASCII text and renders it in ASCII art fonts.

%prep
%setup -q -n pyfiglet-%{version}
sed -i -e '1{/^#!/d}' pyfiglet/__init__.py
mv pyfiglet/test.py .

%build
%pyproject_wheel

%install
%pyproject_install

install -d -m 0755 %{buildroot}%{_mandir}/man1
install -m 0644 doc/pyfiglet.1 %{buildroot}%{_mandir}/man1/

%python_clone -a %{buildroot}%{_mandir}/man1/pyfiglet.1
%python_clone -a %{buildroot}%{_bindir}/pyfiglet

%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Fix python-bytecode-inconsistent-mtime
%python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyfiglet/fonts/
%python_expand $python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyfiglet/fonts/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python test.py

%post
%python_install_alternative pyfiglet pyfiglet.1

%postun
%python_uninstall_alternative pyfiglet pyfiglet.1

%files %{python_files}
%doc README.md doc/figfont.txt
%license LICENSE
%python_alternative %{_bindir}/pyfiglet
%python_alternative %{_mandir}/man1/pyfiglet.1%{ext_man}
%{python_sitelib}/pyfiglet
%{python_sitelib}/pyfiglet-%{version}.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Close file handle in preloadFont
  * Add python3.9 to testing
  * subprocess32 no longer needed
  * Add python_requires >= 3.9
- update to 1.0.0:
  * Update setup.py for python 3.6 and 3.7
  * Add 'make publish' which also publishes wheel (0.8.post1)
  * Add support for zipped fonts
  * Fix simple typo: compatability -> compatibility
  * make color parameter caps
  * add options for handling surrounding whitespace
  * Fix for #89 - clarify font licensing
  * Update __init__.py
  * Add loading German Umlaute
  * Added fonts
  * Support caca2tlf converted fonts better
  * add blocky font
  * Fix setup
  * Revert "Fix setup"
  * Update test.yml python versions
  * Port to importlib.resources
  * seek to the start of the file after checking for a zip header
  * Fix for various font issues
  * Fix most reming font issues
  * Fix #95 - Default fonts if user just runs setup.py
  * Setup auto publish
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed May  8 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Remove tests from runtime package
- Install manpage and add doc/figfont.txt to %%doc
- Update to v0.8
  * Change LICENSE to MIT
  * Provide font installation option (-L) and remove
    unlicenced fonts from the distribution
* Thu Nov  8 2018 Antonio Larrosa <alarrosa@suse.com>
- Remove BuildRequires python-devel
* Tue Nov  6 2018 Jan Engelhardt <jengelh@inai.de>
- Fix typography.
* Mon Nov  5 2018 Todd R <toddrme2178@gmail.com>
- Initial version
